import{A as o}from"./index.997de59d.js";import{d as a,g as r,K as p,b as d,u as c,ec as f,F as l,o as i,Q as u}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="4ee310a5-9384-4663-9416-3af9dd38e3ac",e._sentryDebugIdIdentifier="sentry-dbid-4ee310a5-9384-4663-9416-3af9dd38e3ac")}catch{}})();const _=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,m)=>t.stepsInfo?(i(),p("nav",{key:0,class:f(["p-steps",{"full-screen":!t.isPreview}])},[d(c(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const I=u(_,[["__scopeId","data-v-8b0ea4f1"]]);export{I as S};
//# sourceMappingURL=Steps.86f6e10b.js.map
