import{d as l,en as i,g as r,o,K as t,F as c,ec as g,eb as p,Q as u}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="7b580ece-114a-4dcb-95fc-094a62fb1cea",e._sentryDebugIdIdentifier="sentry-dbid-7b580ece-114a-4dcb-95fc-094a62fb1cea")}catch{}})();const _={class:"logo"},f=["src","alt"],m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;i(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),d=r(()=>`${s.brandName} Logo`);return(a,b)=>(o(),t("div",_,[a.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:a.imageUrl,alt:d.value},null,8,f)):c("",!0),a.hideText?c("",!0):(o(),t("span",{key:1,class:g(a.size)},p(a.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.3a35c761.js.map
