import{P as m}from"./PlayerNavbar.ba91833f.js";import{d as g,e3 as h,e4 as c,f as y,g as b,r as k,K as v,u as n,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.2bd55860.js";import{u as V}from"./workspaceStore.279203c0.js";import"./userStore.826271e3.js";import"./metadata.665ed746.js";import"./PhWebhooksLogo.vue.6d342c2b.js";import"./LoadingOutlined.182e86f7.js";import"./PhSignOut.vue.f455173c.js";import"./index.26647590.js";import"./Avatar.fa219617.js";import"./runnerData.578dbe7d.js";import"./url.8ddd701d.js";import"./colorHelpers.4e11e3ec.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="6f207dbe-01ab-458f-adff-954fddc93cda",o._sentryDebugIdIdentifier="sentry-dbid-6f207dbe-01ab-458f-adff-954fddc93cda")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,a=y(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},f=b(()=>!!c().meta.hideLogin);return(r,s)=>{const _=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(m,{key:0,"current-path":n(d),"hide-login":f.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(_)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.5421acbf.js.map
