import{d as i,c as p,w as n,o as m,b as a,u as t}from"./index.2bd55860.js";import"./linters.5ae2dbb2.js";import{W as s}from"./workspaces.2344942c.js";import{C as d}from"./ContentLayout.4f819aa5.js";import{E as f}from"./controller.1273659b.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.9fdffe1a.js";import"./asyncComputed.8007720a.js";import"./runnerData.578dbe7d.js";import"./url.8ddd701d.js";import"./colorHelpers.4e11e3ec.js";import"./record.5f72dfbb.js";import"./gateway.79c1aab3.js";import"./popupNotifcation.44e16211.js";import"./fetch.ea4c74a7.js";import"./PhPencil.vue.8938602a.js";import"./SaveButton.fb6860cb.js";import"./UnsavedChangesHandler.e7cb4ed5.js";import"./ExclamationCircleOutlined.99265c18.js";import"./CrudView.c237ea79.js";import"./router.562a04cc.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.97173c26.js";import"./PhDotsThreeVertical.vue.4801751a.js";import"./Badge.e8b64a72.js";import"./index.3bcf7d9f.js";import"./index.093686d2.js";import"./polling.2addda62.js";import"./omniChatStore.5537d810.js";import"./index.fc1b0da7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="24bec883-29ac-439d-8908-993670754ba2",o._sentryDebugIdIdentifier="sentry-dbid-24bec883-29ac-439d-8908-993670754ba2")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(m(),p(d,null,{default:n(()=>[a(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.c3d5a8e3.js.map
