import{C as p}from"./controller.1273659b.js";import{d as i,e4 as n,c as s,u as m,o as c}from"./index.2bd55860.js";import{_ as a}from"./View.vue_vue_type_script_setup_true_lang.9fdffe1a.js";import"./gateway.79c1aab3.js";import"./popupNotifcation.44e16211.js";import"./fetch.ea4c74a7.js";import"./record.5f72dfbb.js";import"./PhPencil.vue.8938602a.js";import"./SaveButton.fb6860cb.js";import"./UnsavedChangesHandler.e7cb4ed5.js";import"./ExclamationCircleOutlined.99265c18.js";import"./CrudView.c237ea79.js";import"./router.562a04cc.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.97173c26.js";import"./url.8ddd701d.js";import"./PhDotsThreeVertical.vue.4801751a.js";import"./Badge.e8b64a72.js";import"./index.3bcf7d9f.js";import"./index.093686d2.js";import"./asyncComputed.8007720a.js";import"./polling.2addda62.js";import"./omniChatStore.5537d810.js";import"./index.fc1b0da7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="26829ef6-88ec-4549-acc3-fe32cb88c282",o._sentryDebugIdIdentifier="sentry-dbid-26829ef6-88ec-4549-acc3-fe32cb88c282")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(f,d)=>(c(),s(a,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.d0498913.js.map
