import"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3051a805-7df3-4fc7-8d6c-faa30820a606",e._sentryDebugIdIdentifier="sentry-dbid-3051a805-7df3-4fc7-8d6c-faa30820a606")}catch{}})();function f(e){var n;return(n=e.split(/\/|\\/).pop())!=null?n:""}function o(e){return e.length===0?".":e[e.length-1]}function d(e){const n=["B","KB","MB","GB","TB"],t=e.match(/^(\d+(\.\d+)?)\s*(\w+)$/);if(!t)return 0;const i=parseFloat(t[1]),r=t[3],s=n.indexOf(r);return s===-1?0:i*Math.pow(1024,s)}function u(e){return[".png",".svg",".jpg",".jpeg",".ico",".webp"].some(n=>e.endsWith(n))}export{f as a,o as f,u as i,d as s};
//# sourceMappingURL=files.7d0ee655.js.map
