import{d as a,o,K as s,b as d,u as r,br as _,Q as c}from"./index.2bd55860.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="383f6b62-e99e-4a8e-89b8-600eefcac482",e._sentryDebugIdIdentifier="sentry-dbid-383f6b62-e99e-4a8e-89b8-600eefcac482")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.c7dc16ff.js.map
