import{B as e}from"./BaseLayout.98d04a38.js";import{d as n,e4 as a,r as s,c,w as r,o as u,b as i,u as d}from"./index.2bd55860.js";import{N as f,_}from"./Navbar.11ab97ab.js";import"./OmniChat.af03f6f5.js";import"./gateway.79c1aab3.js";import"./popupNotifcation.44e16211.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.bf726c97.js";import"./Logo.3a35c761.js";import"./uuid.de8c43c5.js";import"./PhClockCounterClockwise.vue.bc63539e.js";import"./omniChatStore.5537d810.js";import"./record.5f72dfbb.js";import"./LoadingOutlined.182e86f7.js";import"./columns.0eb7599e.js";import"./string.fcee8e82.js";import"./linters.5ae2dbb2.js";import"./asyncComputed.8007720a.js";import"./controller.c14fdf47.js";import"./vue-flow-core.b0ecd060.js";import"./validations.edfacc3b.js";import"./metadata.665ed746.js";import"./PhWebhooksLogo.vue.6d342c2b.js";import"./workspaces.2344942c.js";import"./runnerData.578dbe7d.js";import"./url.8ddd701d.js";import"./colorHelpers.4e11e3ec.js";import"./controller.1273659b.js";import"./fetch.ea4c74a7.js";import"./PhPencil.vue.8938602a.js";import"./requirements.7535200a.js";import"./scripts.e3b4956c.js";import"./PhCopySimple.vue.72a497f3.js";import"./index.c56c32e2.js";import"./CollapsePanel.bc815811.js";import"./Avatar.fa219617.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.3d303c38.js";import"./PhArrowCounterClockwise.vue.d70c9e99.js";import"./PhFilePy.vue.3416af62.js";import"./PhChats.vue.7a3c8ffe.js";import"./PhRocket.vue.aa91c39e.js";import"./PhPackage.vue.422e24aa.js";import"./userStore.826271e3.js";import"./polling.2addda62.js";import"./PhArrowSquareOut.vue.59603817.js";import"./PhSignOut.vue.f455173c.js";import"./PhSparkle.vue.ec5f656a.js";import"./editor.c5e900f0.js";import"./workspaceStore.279203c0.js";import"./index.3bcf7d9f.js";import"./CloseCircleOutlined.ea8f9c4c.js";import"./CheckCircleFilled.614fd5dd.js";import"./index.fc1b0da7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="b9810850-3b51-4651-9c50-0c48c5c1bd37",t._sentryDebugIdIdentifier="sentry-dbid-b9810850-3b51-4651-9c50-0c48c5c1bd37")}catch{}})();const _t=n({__name:"Workspace",setup(t){const o=a();return(p,l)=>{const m=s("RouterView");return u(),c(e,null,{navbar:r(()=>[i(f,{"page-title":d(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(m)]),chat:r(()=>[i(_)]),_:1})}}});export{_t as default};
//# sourceMappingURL=Workspace.edd5fb51.js.map
